@@ -1,5 +1,5 @@
 /*
- * Copyright 2001-2022 the original author or authors.
+ * Copyright 2001-2023 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -16,6 +16,7 @@
 package org.easymock.internal;
 
 import org.easymock.EasyMock;
+import org.easymock.EasyMockSupport;
 
 import java.io.*;
 import java.lang.reflect.*;
@@ -44,7 +45,7 @@ public class DefaultClassInstantiator implements IClassInstantiator {
                 return readObject(getSerializedBytes(c));
                 // ///CLOVER:OFF
             } catch (IOException | ClassNotFoundException e) {
-                throw new RuntimeException("Failed to instantiate " + c.getName() + "'s mock: ", e);
+                throw runtimeException(c, e);
             }
             // ///CLOVER:ON
         }
@@ -55,10 +56,14 @@ public class DefaultClassInstantiator implements IClassInstantiator {
             return constructor.newInstance(params);
             // ///CLOVER:OFF
         } catch (IllegalArgumentException | InvocationTargetException | IllegalAccessException e) {
-            throw new RuntimeException("Failed to instantiate " + c.getName() + "'s mock: ", e);
+            throw runtimeException(c, e);
         }
     }
 
+    private RuntimeException runtimeException(Class<?> c, Exception e) {
+        return new RuntimeException("Failed to instantiate " + classToPrint(c).getName() + "'s mock: ", e);
+    }
+
     /**
      * Tells if the provided class is serializable
      *
@@ -86,12 +91,17 @@ public class DefaultClassInstantiator implements IClassInstantiator {
         } catch (NoSuchMethodException e) {
             // If it fails just use the first one
             if (clazz.getConstructors().length == 0) {
-                throw new IllegalArgumentException("No visible constructors in class " + clazz.getName());
+                throw new IllegalArgumentException("No visible constructors in class " + classToPrint(clazz).getName());
             }
             return clazz.getConstructors()[0];
         }
     }
 
+    private Class<?> classToPrint(Class<?> clazz) {
+        // If the class was generated by EasyMock, return the base class so the user knows which of his/her classes went wrong
+        return clazz.getName().contains("$$$EasyMock$") ? clazz.getSuperclass() : clazz;
+    }
+
     /**
      * Get some default instances of provided classes
      *
