@@ -1,5 +1,5 @@
 /*
- * Copyright 2001-2022 the original author or authors.
+ * Copyright 2001-2023 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -20,9 +20,11 @@ import java.io.Serializable;
 import org.easymock.IArgumentMatcher;
 
 /**
+ * Base class for matchers that are comparing a value to another.
+ *
  * @param <T>
  *            Type of the values compared
- * 
+ *
  * @author Henri Tremblay
  */
 public abstract class CompareTo<T extends Comparable<T>> implements IArgumentMatcher, Serializable {
@@ -45,6 +47,7 @@ public abstract class CompareTo<T extends Comparable<T>> implements IArgumentMat
         return matchResult(((Comparable) actual).compareTo(expected));
     }
 
+    @Override
     public void appendTo(StringBuffer buffer) {
         buffer.append(getName()).append("(").append(expected).append(")");
     }
