@@ -1,5 +1,5 @@
 /*
- * Copyright 2001-2022 the original author or authors.
+ * Copyright 2001-2023 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -20,6 +20,8 @@ import java.io.Serializable;
 import org.easymock.IArgumentMatcher;
 
 /**
+ * Matches if the argument is null.
+ *
  * @author OFFIS, Tammo Freese
  */
 public class Null implements IArgumentMatcher, Serializable {
@@ -31,10 +33,12 @@ public class Null implements IArgumentMatcher, Serializable {
     private Null() {
     }
 
+    @Override
     public boolean matches(Object actual) {
         return actual == null;
     }
 
+    @Override
     public void appendTo(StringBuffer buffer) {
         buffer.append("isNull()");
     }
