@@ -1,5 +1,5 @@
 /*
- * Copyright 2001-2022 the original author or authors.
+ * Copyright 2001-2023 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -17,11 +17,11 @@ package org.easymock.samples;
 
 import org.easymock.EasyMockSupport;
 import org.easymock.IMocksControl;
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 import static org.easymock.EasyMock.*;
-import static org.junit.Assert.*;
 
 /**
  * @author Henri Tremblay
@@ -34,7 +34,7 @@ public class SupportDelegationTest {
 
     private ClassTested classUnderTest;
 
-    @Before
+    @BeforeEach
     public void setup() {
         classUnderTest = new ClassTested();
     }
@@ -65,7 +65,7 @@ public class SupportDelegationTest {
         support.replayAll();
 
         classUnderTest.addDocument("Document 1", "content");
-        assertTrue(classUnderTest.removeDocuments("Document 1"));
+        Assertions.assertTrue(classUnderTest.removeDocuments("Document 1"));
 
         support.verifyAll();
     }
