@@ -1,5 +1,5 @@
 /*
- * Copyright 2001-2022 the original author or authors.
+ * Copyright 2001-2023 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -15,7 +15,8 @@
  */
 package org.easymock.internal;
 
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 
 import static org.junit.Assert.*;
 
@@ -29,8 +30,8 @@ public class LinkedClassLoaderTest {
         OneClassLoader stringLoader = new OneClassLoader(String.class.getName(), getClass().getClassLoader());
         OneClassLoader testLoader = new OneClassLoader(getClass().getName(), getClass().getClassLoader());
         LinkedClassLoader classLoader = new LinkedClassLoader(stringLoader, testLoader);
-        assertSame(String.class, classLoader.findClass(String.class.getName()));
-        assertSame(getClass(), classLoader.findClass(getClass().getName()));
+        Assertions.assertSame(String.class, classLoader.findClass(String.class.getName()));
+        Assertions.assertSame(getClass(), classLoader.findClass(getClass().getName()));
 
         assertThrows(ClassNotFoundException.class, () -> classLoader.findClass(Test.class.getName()));
     }
