@@ -1,5 +1,5 @@
 /*
- * Copyright 2001-2022 the original author or authors.
+ * Copyright 2001-2023 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -15,12 +15,11 @@
  */
 package org.easymock.tests;
 
-import static org.junit.Assert.*;
-
 import java.lang.reflect.Method;
 
 import org.easymock.internal.MethodSerializationWrapper;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 
 /**
  * @author OFFIS, Tammo Freese
@@ -38,7 +37,7 @@ public class MethodSerializationWrapperTest {
         Method foo = A.class.getMethod("foo", String.class, Integer.TYPE, String[].class, int[].class,
                 String[].class);
         MethodSerializationWrapper wrapper = new MethodSerializationWrapper(foo);
-        assertEquals(foo, wrapper.getMethod());
+        Assertions.assertEquals(foo, wrapper.getMethod());
     }
 
 }
