@@ -1,5 +1,5 @@
 /*
- * Copyright 2001-2022 the original author or authors.
+ * Copyright 2001-2023 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -15,10 +15,10 @@
  */
 package org.easymock.tests;
 
-import static org.easymock.EasyMock.*;
-import static org.junit.Assert.*;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 
-import org.junit.Test;
+import static org.easymock.EasyMock.*;
 
 /**
  * @author OFFIS, Tammo Freese
@@ -30,6 +30,6 @@ public class MockNameTest {
         IMethods mock = createMock(IMethods.class);
         String expected = "EasyMock for " + IMethods.class;
         String actual = mock.toString();
-        assertEquals(expected, actual);
+        Assertions.assertEquals(expected, actual);
     }
 }
