@@ -1,5 +1,5 @@
 /*
- * Copyright 2001-2022 the original author or authors.
+ * Copyright 2001-2023 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -16,10 +16,10 @@
 package org.easymock.tests;
 
 import static org.easymock.EasyMock.*;
-import static org.junit.Assert.*;
 
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 /**
  * @author OFFIS, Tammo Freese
@@ -32,7 +32,7 @@ public class UsageCallCountTest {
         void method();
     }
 
-    @Before
+    @BeforeEach
     public void setup() {
         mock = createMock(VoidMethodInterface.class);
     }
@@ -114,7 +114,7 @@ public class UsageCallCountTest {
     private void assertVerifyFails() {
         try {
             verify(mock);
-            fail("Expected AssertionError");
+            Assertions.fail("Expected AssertionError");
         } catch (AssertionError expected) {
         }
     }
@@ -122,7 +122,7 @@ public class UsageCallCountTest {
     private void assertMethodCallFails() {
         try {
             mock.method();
-            fail("Expected AssertionError");
+            Assertions.fail("Expected AssertionError");
         } catch (AssertionError expected) {
         }
     }
