@@ -1,5 +1,5 @@
 /*
- * Copyright 2001-2022 the original author or authors.
+ * Copyright 2001-2023 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -16,10 +16,10 @@
 package org.easymock.tests;
 
 import static org.easymock.EasyMock.*;
-import static org.junit.Assert.*;
 
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 /**
  * @author OFFIS, Tammo Freese
@@ -30,7 +30,7 @@ public class UsageExpectAndThrowTest {
 
     private static RuntimeException EXCEPTION = new RuntimeException();
 
-    @Before
+    @BeforeEach
     public void setup() {
         mock = createMock(IMethods.class);
     }
@@ -41,9 +41,9 @@ public class UsageExpectAndThrowTest {
         replay(mock);
         try {
             mock.booleanReturningMethod(4);
-            fail();
+            Assertions.fail();
         } catch (RuntimeException exception) {
-            assertSame(EXCEPTION, exception);
+            Assertions.assertSame(EXCEPTION, exception);
         }
         verify(mock);
     }
@@ -54,9 +54,9 @@ public class UsageExpectAndThrowTest {
         replay(mock);
         try {
             mock.longReturningMethod(4);
-            fail();
+            Assertions.fail();
         } catch (RuntimeException exception) {
-            assertSame(EXCEPTION, exception);
+            Assertions.assertSame(EXCEPTION, exception);
         }
         verify(mock);
     }
@@ -67,9 +67,9 @@ public class UsageExpectAndThrowTest {
         replay(mock);
         try {
             mock.floatReturningMethod(4);
-            fail();
+            Assertions.fail();
         } catch (RuntimeException exception) {
-            assertSame(EXCEPTION, exception);
+            Assertions.assertSame(EXCEPTION, exception);
         }
         verify(mock);
     }
@@ -80,9 +80,9 @@ public class UsageExpectAndThrowTest {
         replay(mock);
         try {
             mock.doubleReturningMethod(4);
-            fail();
+            Assertions.fail();
         } catch (RuntimeException exception) {
-            assertSame(EXCEPTION, exception);
+            Assertions.assertSame(EXCEPTION, exception);
         }
         verify(mock);
     }
@@ -93,9 +93,9 @@ public class UsageExpectAndThrowTest {
         replay(mock);
         try {
             mock.objectReturningMethod(4);
-            fail();
+            Assertions.fail();
         } catch (RuntimeException exception) {
-            assertSame(EXCEPTION, exception);
+            Assertions.assertSame(EXCEPTION, exception);
         }
         verify(mock);
     }
@@ -106,9 +106,9 @@ public class UsageExpectAndThrowTest {
         replay(mock);
         try {
             mock.booleanReturningMethod(4);
-            fail();
+            Assertions.fail();
         } catch (RuntimeException exception) {
-            assertSame(EXCEPTION, exception);
+            Assertions.assertSame(EXCEPTION, exception);
         }
         verify(mock);
     }
@@ -119,9 +119,9 @@ public class UsageExpectAndThrowTest {
         replay(mock);
         try {
             mock.longReturningMethod(4);
-            fail();
+            Assertions.fail();
         } catch (RuntimeException exception) {
-            assertSame(EXCEPTION, exception);
+            Assertions.assertSame(EXCEPTION, exception);
         }
         verify(mock);
     }
@@ -132,9 +132,9 @@ public class UsageExpectAndThrowTest {
         replay(mock);
         try {
             mock.floatReturningMethod(4);
-            fail();
+            Assertions.fail();
         } catch (RuntimeException exception) {
-            assertSame(EXCEPTION, exception);
+            Assertions.assertSame(EXCEPTION, exception);
         }
         verify(mock);
     }
@@ -145,9 +145,9 @@ public class UsageExpectAndThrowTest {
         replay(mock);
         try {
             mock.doubleReturningMethod(4);
-            fail();
+            Assertions.fail();
         } catch (RuntimeException exception) {
-            assertSame(EXCEPTION, exception);
+            Assertions.assertSame(EXCEPTION, exception);
         }
         verify(mock);
     }
@@ -158,9 +158,9 @@ public class UsageExpectAndThrowTest {
         replay(mock);
         try {
             mock.objectReturningMethod(4);
-            fail();
+            Assertions.fail();
         } catch (RuntimeException exception) {
-            assertSame(EXCEPTION, exception);
+            Assertions.assertSame(EXCEPTION, exception);
         }
         verify(mock);
     }
@@ -171,15 +171,15 @@ public class UsageExpectAndThrowTest {
         replay(mock);
         try {
             mock.booleanReturningMethod(4);
-            fail();
+            Assertions.fail();
         } catch (RuntimeException exception) {
-            assertSame(EXCEPTION, exception);
+            Assertions.assertSame(EXCEPTION, exception);
         }
         try {
             mock.booleanReturningMethod(4);
-            fail();
+            Assertions.fail();
         } catch (RuntimeException exception) {
-            assertSame(EXCEPTION, exception);
+            Assertions.assertSame(EXCEPTION, exception);
         }
         verify(mock);
     }
@@ -190,15 +190,15 @@ public class UsageExpectAndThrowTest {
         replay(mock);
         try {
             mock.longReturningMethod(4);
-            fail();
+            Assertions.fail();
         } catch (RuntimeException exception) {
-            assertSame(EXCEPTION, exception);
+            Assertions.assertSame(EXCEPTION, exception);
         }
         try {
             mock.longReturningMethod(4);
-            fail();
+            Assertions.fail();
         } catch (RuntimeException exception) {
-            assertSame(EXCEPTION, exception);
+            Assertions.assertSame(EXCEPTION, exception);
         }
         verify(mock);
     }
@@ -209,15 +209,15 @@ public class UsageExpectAndThrowTest {
         replay(mock);
         try {
             mock.floatReturningMethod(4);
-            fail();
+            Assertions.fail();
         } catch (RuntimeException exception) {
-            assertSame(EXCEPTION, exception);
+            Assertions.assertSame(EXCEPTION, exception);
         }
         try {
             mock.floatReturningMethod(4);
-            fail();
+            Assertions.fail();
         } catch (RuntimeException exception) {
-            assertSame(EXCEPTION, exception);
+            Assertions.assertSame(EXCEPTION, exception);
         }
         verify(mock);
     }
@@ -228,15 +228,15 @@ public class UsageExpectAndThrowTest {
         replay(mock);
         try {
             mock.doubleReturningMethod(4);
-            fail();
+            Assertions.fail();
         } catch (RuntimeException exception) {
-            assertSame(EXCEPTION, exception);
+            Assertions.assertSame(EXCEPTION, exception);
         }
         try {
             mock.doubleReturningMethod(4);
-            fail();
+            Assertions.fail();
         } catch (RuntimeException exception) {
-            assertSame(EXCEPTION, exception);
+            Assertions.assertSame(EXCEPTION, exception);
         }
         verify(mock);
     }
@@ -247,15 +247,15 @@ public class UsageExpectAndThrowTest {
         replay(mock);
         try {
             mock.objectReturningMethod(4);
-            fail();
+            Assertions.fail();
         } catch (RuntimeException exception) {
-            assertSame(EXCEPTION, exception);
+            Assertions.assertSame(EXCEPTION, exception);
         }
         try {
             mock.objectReturningMethod(4);
-            fail();
+            Assertions.fail();
         } catch (RuntimeException exception) {
-            assertSame(EXCEPTION, exception);
+            Assertions.assertSame(EXCEPTION, exception);
         }
         verify(mock);
     }
@@ -266,22 +266,22 @@ public class UsageExpectAndThrowTest {
         replay(mock);
         try {
             mock.booleanReturningMethod(4);
-            fail();
+            Assertions.fail();
         } catch (RuntimeException exception) {
-            assertSame(EXCEPTION, exception);
+            Assertions.assertSame(EXCEPTION, exception);
         }
         try {
             mock.booleanReturningMethod(4);
-            fail();
+            Assertions.fail();
         } catch (RuntimeException exception) {
-            assertSame(EXCEPTION, exception);
+            Assertions.assertSame(EXCEPTION, exception);
         }
         verify(mock);
         try {
             mock.booleanReturningMethod(4);
-            fail();
+            Assertions.fail();
         } catch (RuntimeException exception) {
-            assertSame(EXCEPTION, exception);
+            Assertions.assertSame(EXCEPTION, exception);
         }
         verify(mock);
     }
@@ -292,22 +292,22 @@ public class UsageExpectAndThrowTest {
         replay(mock);
         try {
             mock.longReturningMethod(4);
-            fail();
+            Assertions.fail();
         } catch (RuntimeException exception) {
-            assertSame(EXCEPTION, exception);
+            Assertions.assertSame(EXCEPTION, exception);
         }
         try {
             mock.longReturningMethod(4);
-            fail();
+            Assertions.fail();
         } catch (RuntimeException exception) {
-            assertSame(EXCEPTION, exception);
+            Assertions.assertSame(EXCEPTION, exception);
         }
         verify(mock);
         try {
             mock.longReturningMethod(4);
-            fail();
+            Assertions.fail();
         } catch (RuntimeException exception) {
-            assertSame(EXCEPTION, exception);
+            Assertions.assertSame(EXCEPTION, exception);
         }
         verify(mock);
     }
@@ -318,22 +318,22 @@ public class UsageExpectAndThrowTest {
         replay(mock);
         try {
             mock.floatReturningMethod(4);
-            fail();
+            Assertions.fail();
         } catch (RuntimeException exception) {
-            assertSame(EXCEPTION, exception);
+            Assertions.assertSame(EXCEPTION, exception);
         }
         try {
             mock.floatReturningMethod(4);
-            fail();
+            Assertions.fail();
         } catch (RuntimeException exception) {
-            assertSame(EXCEPTION, exception);
+            Assertions.assertSame(EXCEPTION, exception);
         }
         verify(mock);
         try {
             mock.floatReturningMethod(4);
-            fail();
+            Assertions.fail();
         } catch (RuntimeException exception) {
-            assertSame(EXCEPTION, exception);
+            Assertions.assertSame(EXCEPTION, exception);
         }
         verify(mock);
     }
@@ -344,22 +344,22 @@ public class UsageExpectAndThrowTest {
         replay(mock);
         try {
             mock.doubleReturningMethod(4);
-            fail();
+            Assertions.fail();
         } catch (RuntimeException exception) {
-            assertSame(EXCEPTION, exception);
+            Assertions.assertSame(EXCEPTION, exception);
         }
         try {
             mock.doubleReturningMethod(4);
-            fail();
+            Assertions.fail();
         } catch (RuntimeException exception) {
-            assertSame(EXCEPTION, exception);
+            Assertions.assertSame(EXCEPTION, exception);
         }
         verify(mock);
         try {
             mock.doubleReturningMethod(4);
-            fail();
+            Assertions.fail();
         } catch (RuntimeException exception) {
-            assertSame(EXCEPTION, exception);
+            Assertions.assertSame(EXCEPTION, exception);
         }
         verify(mock);
     }
@@ -370,22 +370,22 @@ public class UsageExpectAndThrowTest {
         replay(mock);
         try {
             mock.objectReturningMethod(4);
-            fail();
+            Assertions.fail();
         } catch (RuntimeException exception) {
-            assertSame(EXCEPTION, exception);
+            Assertions.assertSame(EXCEPTION, exception);
         }
         try {
             mock.objectReturningMethod(4);
-            fail();
+            Assertions.fail();
         } catch (RuntimeException exception) {
-            assertSame(EXCEPTION, exception);
+            Assertions.assertSame(EXCEPTION, exception);
         }
         verify(mock);
         try {
             mock.objectReturningMethod(4);
-            fail();
+            Assertions.fail();
         } catch (RuntimeException exception) {
-            assertSame(EXCEPTION, exception);
+            Assertions.assertSame(EXCEPTION, exception);
         }
         verify(mock);
     }
