@@ -1,5 +1,5 @@
 /*
- * Copyright 2001-2022 the original author or authors.
+ * Copyright 2001-2023 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -16,10 +16,10 @@
 package org.easymock.tests;
 
 import static org.easymock.EasyMock.*;
-import static org.junit.Assert.*;
 
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 /**
  * @author OFFIS, Tammo Freese
@@ -28,7 +28,7 @@ public class UsageLongCompatibleReturnValueTest {
 
     private IMethods mock;
 
-    @Before
+    @BeforeEach
     public void setup() {
         mock = createMock(IMethods.class);
     }
@@ -40,9 +40,9 @@ public class UsageLongCompatibleReturnValueTest {
 
         replay(mock);
 
-        assertEquals((byte) 25, mock.byteReturningMethod(0));
-        assertEquals((byte) 34, mock.byteReturningMethod(-4));
-        assertEquals((byte) 34, mock.byteReturningMethod(12));
+        Assertions.assertEquals((byte) 25, mock.byteReturningMethod(0));
+        Assertions.assertEquals((byte) 34, mock.byteReturningMethod(-4));
+        Assertions.assertEquals((byte) 34, mock.byteReturningMethod(12));
 
         verify(mock);
     }
@@ -54,9 +54,9 @@ public class UsageLongCompatibleReturnValueTest {
 
         replay(mock);
 
-        assertEquals((short) 25, mock.shortReturningMethod(0));
-        assertEquals((short) 34, mock.shortReturningMethod(-4));
-        assertEquals((short) 34, mock.shortReturningMethod(12));
+        Assertions.assertEquals((short) 25, mock.shortReturningMethod(0));
+        Assertions.assertEquals((short) 34, mock.shortReturningMethod(-4));
+        Assertions.assertEquals((short) 34, mock.shortReturningMethod(12));
 
         verify(mock);
     }
@@ -68,9 +68,9 @@ public class UsageLongCompatibleReturnValueTest {
 
         replay(mock);
 
-        assertEquals((char) 25, mock.charReturningMethod(0));
-        assertEquals((char) 34, mock.charReturningMethod(-4));
-        assertEquals((char) 34, mock.charReturningMethod(12));
+        Assertions.assertEquals((char) 25, mock.charReturningMethod(0));
+        Assertions.assertEquals((char) 34, mock.charReturningMethod(-4));
+        Assertions.assertEquals((char) 34, mock.charReturningMethod(12));
 
         verify(mock);
     }
@@ -82,9 +82,9 @@ public class UsageLongCompatibleReturnValueTest {
 
         replay(mock);
 
-        assertEquals(25, mock.intReturningMethod(0));
-        assertEquals(34, mock.intReturningMethod(-4));
-        assertEquals(34, mock.intReturningMethod(12));
+        Assertions.assertEquals(25, mock.intReturningMethod(0));
+        Assertions.assertEquals(34, mock.intReturningMethod(-4));
+        Assertions.assertEquals(34, mock.intReturningMethod(12));
 
         verify(mock);
     }
@@ -96,9 +96,9 @@ public class UsageLongCompatibleReturnValueTest {
 
         replay(mock);
 
-        assertEquals(25, mock.longReturningMethod(0));
-        assertEquals(34, mock.longReturningMethod(-4));
-        assertEquals(34, mock.longReturningMethod(12));
+        Assertions.assertEquals(25, mock.longReturningMethod(0));
+        Assertions.assertEquals(34, mock.longReturningMethod(-4));
+        Assertions.assertEquals(34, mock.longReturningMethod(12));
 
         verify(mock);
     }
