@@ -1,5 +1,5 @@
 /*
- * Copyright 2015-2022 the original author or authors.
+ * Copyright 2015-2023 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -15,10 +15,10 @@
  */
 package org.itests;
 
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 import java.io.IOException;
-import java.nio.CharBuffer;
+import java.io.PrintStream;
 
 import static org.easymock.EasyMock.*;
 
@@ -36,8 +36,8 @@ public class NoDepsTest {
 
     @Test
     public void classMocking() throws Exception {
-        CharBuffer buffer =mock(CharBuffer.class);
-        test(buffer);
+        PrintStream stream = mock(PrintStream.class);
+        test(stream);
     }
 
     private void test(Appendable appendable) throws IOException {
